@@ -118,7 +118,7 @@ class WeChatWorkSDK(ValidationMixin):
         url = f'{self.API_ROOT_URL}/message/send?access_token={self.access_token}'
         return requests.post(url, json=data)
 
-    def send_file(self, path, type='file'):
+    def send_file(self, path, type='file', touser="7683", agentid=1000041):
         upload_media_url = f"{self.API_ROOT_URL}/media/upload?access_token={self.access_token}&type={type}"
 
         with open(path, 'rb') as f:
@@ -126,8 +126,21 @@ class WeChatWorkSDK(ValidationMixin):
             response = requests.post(upload_media_url, files=files)
         try:
             media_id = response.json()['media_id']
-            body = {"msgtype": type, type: {"media_id": media_id}}
-            return self._send(body)
+
+            data = {
+                "touser": touser,  # "@all"
+
+                "msgtype": type,
+                "agentid": agentid,
+                type: {
+                    "media_id": media_id
+                },
+                "safe": 0,
+                "enable_id_trans": 0,
+                "enable_duplicate_check": 0
+            }
+
+            return self._send(data)
 
         except Exception as e:
             print(e)
